CurvePoint — pyqtgraph 0.11.0rc0 documentation

# CurvePoint

class `pyqtgraph.` `CurvePoint`(curve, index=0, pos=None, rotate=True)

  A GraphicsItem that sets its location to a point on a PlotCurveItem. Also rotates to be tangent to the curve. The position along the curve is a Qt property, and thus can be easily animated.

  Note: This class does not display anything; see CurveArrow for an applied example

  `__init__`(curve, index=0, pos=None, rotate=True)

    Position can be set either as an index referring to the sample number or the position 0.0 - 1.0 If rotate is True, then the item rotates to match the tangent of the curve.

  `boundingRect`(self) → PySide2.QtCore.QRectF
  `event`(self, ev: PySide2.QtCore.QEvent) → bool
  `paint`(self, painter: PySide2.QtGui.QPainter, option: PySide2.QtWidgets.QStyleOptionGraphicsItem, widget: typing.Union[PySide2.QtWidgets.QWidget, NoneType] = None)
  `setPos`(self, pos: PySide2.QtCore.QPointF)

    setPos(self, x: float, y: float)